package kosoft.utils.redirectstdio;

// redirectstdio library to redirect java stdout/stderr to timestamped & size rolled file. 
// Copyright (C) 2000 Mark O'Donohue [ mark.odonohue@gmail.com] 

// This library is free software; you can redistribute it and/or modify it under the terms of the GNU 
// Lesser General Public License as published by the Free Software Foundation; either version 2.1 of 
// the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
// even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
// Lesser General Public License for more details.


import java.util.*;
import java.util.Date;
import java.io.*;


public class RuntimeProperties {
    Properties runParameters = new Properties();
	
    String propertyFileName = "test.properties";

    public void setFileName(String newName) { propertyFileName = newName; }

    public void load(String filename)  {
		setFileName(filename);
		load();
    }

    public void load()  {
        File loadFile = new File(propertyFileName);
        if (!loadFile.exists()) {
            throw new RuntimeException("Missing required property file : " + propertyFileName);
        }
        
        try { 
        	FileInputStream input = new FileInputStream(loadFile);
        	runParameters.load(input);
        }
        catch (FileNotFoundException e) {
        	throw new RuntimeException("FileNotFoundException: " + propertyFileName);
        	
        }
        catch (IOException e) {
        	throw new RuntimeException("IOException reading:" + propertyFileName);        	
        }
    }

    public Properties getProperties() { return runParameters; }
    
    public String getProperty(String key)  {
        String value = getProperty(key, null);
        if (value == null) {
            throw new RuntimeException("Missing required property " + key + " from " + propertyFileName);
        }
        return value;
    }
    
    public String getProperty(String key, String defaultValue) {
        String value = runParameters.getProperty(key);
        if (value == null) {
            value = defaultValue;
        }
        return value;
    }

   public double getPropertyAsDouble(String key)  {
       String valueString = getProperty(key);
       double value = -1.0;
       try {
           value = Double.parseDouble(valueString);
       }
       catch (NumberFormatException  e) {
            throw new RuntimeException("Unable to parse number from " + value + "for key " + key + " in " + propertyFileName);
       }
       return value;
    }

   public double getPropertyAsDouble(String key, double defaultValue) {
       double value = defaultValue;

       String valueString = getProperty(key, null);
       if (valueString != null) {
           try {
               value = Double.parseDouble(valueString);
           }
           catch (NumberFormatException  e) {}
       }
       return value;
    }

   public int getPropertyAsInt(String key) {
       int value = -1;
       try {
	       String valueString = getProperty(key);
           value = Integer.parseInt(valueString);
       }
       catch (NumberFormatException  e) {
            throw new RuntimeException("Unable to parse number from " + value + "for key " + key + " in " + propertyFileName);
       }
       return value;
    }

   public int getPropertyAsInt(String key, int defaultValue) {
       int value = defaultValue;

       String valueString = getProperty(key, null);
       if (valueString != null) {
           try {
               value = Integer.parseInt(valueString);
           }
           catch (NumberFormatException  e) {}
       }
       return value;
    }

   public long getPropertyAsLong(String key) {
       long value = -1;
       try {
	       String valueString = getProperty(key);
           value = Long.parseLong(valueString);
       }
       catch (NumberFormatException  e) {
            throw new RuntimeException("Unable to parse number from " + value + "for key " + key + " in " + propertyFileName);
       }
       return value;
    }

   public long getPropertyAsLong(String key, long defaultValue) {
       long value = defaultValue;

       String valueString = getProperty(key, null);
       if (valueString != null) {
           try {
               value = Long.parseLong(valueString);
           }
           catch (NumberFormatException  e) {}
       }
       return value;
    }
   
   public boolean getPropertyAsBoolean(String key, boolean defaultValue) {
       boolean value = defaultValue;

       String valueString = getProperty(key, null);
       if (valueString != null) {
           if (valueString.toLowerCase().startsWith("t")) {
               value = true;
           }
           else if (valueString.toLowerCase().startsWith("f")) {
               value = false;
           }               
       }
       return value;
    }
}

